/**
 * 版权所有 ©2019 莱欧软件有限公司
 * 工程名：testMvc
 * 文件名：LiginController.java
 * 创建日期：2019年2月26日 下午2:04:31
 * 作者：dlm
 */
package com.lion.controller;

import java.awt.Color;
import java.awt.Font;
import java.awt.Graphics;
import java.awt.image.BufferedImage;
import java.io.IOException;
import java.util.Map;
import java.util.Random;

import javax.imageio.ImageIO;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.lion.service.LoginService;
import com.lion.util.Util;


/**
 * 类描述  登录
 * @author dlm
 * @since 2019年2月26日
 */
@RestController
@RequestMapping("login")
public class LoginController {
	@Autowired
	private LoginService service;
	@Value("#{configProperties['loginOut']}") 
	private String loginOut;
	
	@Value("#{configProperties['private_key']}") // 读取配置文件的属性
	private String private_key;
	/** 
	 * 方法描述  组织机构用户登录
	 * @author dlm
	 * @since 2019年3月14日
	 * @param req
	 * @param session
	 * @param userName
	 * @param password
	 * @param code
	 * @return	
	 */
	@RequestMapping("userLogin.do")
	public String userLoginManager(HttpServletRequest req,HttpServletResponse res,HttpSession session,String userName,String password,String code){
		return service.userLoginManager(req, res, session, userName, password, code,private_key);
	}
	
	/**
	 * 方法描述 根据当前用户登录的角色获取资源
	 * @author dlm
	 * @since 2019年2月27日
	 * @param req
	 * @return	
	 */
	@RequestMapping("getResourcesByRole.service")
	public Map<String,Object> getResourcesByRole(HttpServletRequest req,HttpSession session){
		return service.getResourcesByRole(req, session);
	}
	/**
	 * 方法描述  安全退出
	 * @author dlm
	 * @since 2019年3月1日
	 * @param req
	 * @param session
	 * @return	
	 */
	@RequestMapping("loginOut.service")
	public String loginOut(HttpServletRequest req,HttpSession session){
		service.loginOut(session,loginOut);
		return Util.responseString("true", "../login.html");
	}
	@RequestMapping("loginOut.do")
	public String loginOutDo(HttpServletRequest req,HttpSession session){
		service.loginOut(session,loginOut);
		return Util.responseString("true", "../login.html");
	}
	/**
	 * 方法描述  生成验证码
	 * @author dlm
	 * @since 2019年3月1日
	 * @param req
	 * @param timestamp  时间戳
	 * @return	
	 * @throws IOException 
	 */
	@RequestMapping("createImg.do")
	public void createImg(HttpServletRequest req,HttpSession session,String timestamp,HttpServletResponse res) throws IOException{
		String str="ABCDEFGHIGKLMNOPQRSTUVWXYZ0123456789";
		int width=80;//宽度
		int height=38;//验证码高度
		BufferedImage buffImg = new BufferedImage(width, height, BufferedImage.TYPE_INT_RGB);
		Graphics gd = buffImg.getGraphics();
		gd.setColor(Color.WHITE);
		gd.fillRect(0, 0, width, height);
		Random r = new Random();
		StringBuffer sb = new StringBuffer();
		for (int i = 0; i < 4; i++) {
			gd.setColor(new Color(r.nextInt(88), r.nextInt(210), r.nextInt(150)));
			String code=str.charAt(new Random().nextInt(str.length()))+"";
			gd.setFont(new Font("微软雅黑",Font.PLAIN,22));//字体及大小
			gd.drawString(code, 15 * i + 7, 27);
			sb.append(code);
		}
		session.setAttribute("ecode",sb.toString());
		gd.drawRect(0, 0, width - 1, height - 1);
		ImageIO.write(buffImg, "jpg", res.getOutputStream());
	}
	
	/**
	 * 方法描述	修改密码
	 * @author cpf
	 * @since 2019年3月7日
	 * @return	
	 */
	@RequestMapping("submitPassword.service")
	public String updatePassword(HttpServletRequest req,HttpSession session,String password,String confirm_password){
		return service.updatePassword(req, session, password, confirm_password);
	}
	@RequestMapping("returnUserInfo.service")
	public Map<String,Object> returnUserInfo(HttpServletRequest req){
		return service.returnUserInfo(req);
	}
}
