/**
 * 版权所有 ©2021 莱欧有限公司
 * 工程名：yearBooks
 * 文件名：FruitDao.java
 * 创建日期：2021年10月28日 上午8:54:07
 * 作者：mt.W
 */
package com.lion.dao;

import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.stereotype.Repository;

import com.lion.entity.Fruit;

import jodd.util.StringUtil;

/**
 * 类描述   种植业指标-水果类别 Dao
 * @author mt.W
 * @since 2021年10月28日
 */
@Repository
public class FruitDao {

	@Autowired
	private JdbcTemplate jdbc;
	
	/**
	 * 
	 * 方法描述   查询类别列表
	 * @author mt.W
	 * @since 2021年10月28日
	 * @param start
	 * @param limit
	 * @param name
	 * @return
	 */
	public List<Map<String, Object>> getTypeList(int start,int limit,String name){
		String sql = "select * from zzy_jcsg ";
		if(StringUtil.isNotEmpty(name)){
			sql += " where name like '%"+name+"%' ";
		}
		sql += " order by createTime desc limit ?,? ";
		return jdbc.queryForList(sql,new Object[]{start,limit});
	}
	public List<Map<String,Object>> getTypeList(){
		String sql = "select id,name from zzy_jcsg ";
		return jdbc.queryForList(sql);
	}
	/**
	 * 
	 * 方法描述   查询类别数量
	 * @author mt.W
	 * @since 2021年10月28日
	 * @param name
	 * @return
	 */
	public int getTypeCount(String name){
		String sql = "select count(id) from zzy_jcsg ";
		if(StringUtil.isNotEmpty(name)){
			sql += " where name like '%"+name+"%' ";
		}
		return jdbc.queryForObject(sql, Integer.class);
	}
	/**
	 * 
	 * 方法描述  新增类别
	 * @author mt.W
	 * @since 2021年10月28日
	 * @param f
	 * @return
	 */
	public int addType(Fruit f){
		String sql = "insert into zzy_jcsg(name,createTime,createUser) values(?,?,?)";
		return jdbc.update(sql,new Object[]{f.getName(),f.getCreateTime(),f.getCreateUser()});
	}
	/**
	 * 
	 * 方法描述  修改类别
	 * @author mt.W
	 * @since 2021年10月28日
	 * @param f
	 * @return
	 */
	public int editType(Fruit f){
		String sql = "update zzy_jcsg set name =?,updateTime=?,updateUser=? where id = ?";
		return jdbc.update(sql,new Object[]{f.getName(),f.getUpdateTime(),f.getUpdateUser(),f.getId()});
	}
	/**
	 * 
	 * 方法描述  删除类别
	 * @author mt.W
	 * @since 2021年10月28日
	 * @param id
	 * @return
	 */
	public int deleteType(String id){
		String sql = "delete from zzy_jcsg where id = ? ";
		return jdbc.update(sql,new Object[]{id});
	}
	/**
	 * 
	 * 方法描述  查询类别是否已存在
	 * @author mt.W
	 * @since 2021年10月28日
	 * @param name
	 * @param id
	 * @return
	 */
	public int getCheckType(String name,String id){
		String sql = "select count(id) from zzy_jcsg where name = ? ";
		if(StringUtil.isNotEmpty(id)){
			sql += " and id != '"+id+"' ";
		}
		return jdbc.queryForObject(sql, new Object[]{name},Integer.class);
	}
	/**
	 * 
	 * 方法描述   查看水果类别是否已存入数据
	 * @author mt.W
	 * @since 2021年10月28日
	 * @param id
	 * @return
	 */
	public int checkUseType(String id){
		String sql = "select count(id) from zzy_sg where typeId = ? ";
		return jdbc.queryForObject(sql,new Object[]{id}, Integer.class);
	}
}
