/**
 * 版权所有 ©2021 莱欧有限公司
 * 工程名：yearBooks
 * 文件名：ZzyJjzwDao.java
 * 创建日期：2021年10月26日 下午2:52:28
 * 作者：mt.W
 */
package com.lion.dao;

import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.stereotype.Repository;

import com.lion.entity.ZzyJjzw;

import jodd.util.StringUtil;

/**
 * 类描述   种植业指标-主要经济作物
 * @author mt.W
 * @since 2021年10月26日
 */
@Repository
public class ZzyJjzwDao {

	@Autowired
	private JdbcTemplate jdbc;
	
	/**
	 * 
	 * 方法描述   查询记录
	 * @author mt.W
	 * @since 2021年10月26日
	 * @param start
	 * @param limit
	 * @param year
	 * @param orgid
	 * @return
	 */
	public List<Map<String, Object>> getRecordList(int start,int limit,String year,String orgid){
		String sql = "select z.*,o.name orgname from zzy_jjzw z left join orgdept o on o.id = z.orgid where z.orgid like '"+orgid+"%' ";
		if(StringUtil.isNotEmpty(year)){
			sql += " and z.year = '"+year+"' ";
		}
		sql += " order by z.year desc limit ?,? ";
		return jdbc.queryForList(sql,new Object[]{start,limit});
	}
	/**
	 * 
	 * 方法描述  查询记录
	 * @author mt.W
	 * @since 2021年10月26日
	 * @param year
	 * @param orgid
	 * @return
	 */
	public List<Map<String, Object>> getRecordList(String year,String orgid){
		String sql = "select z.*,o.name orgname from zzy_jjzw z left join orgdept o on o.id = z.orgid where z.orgid like '"+orgid+"%' ";
		if(StringUtil.isNotEmpty(year)){
			sql += " and z.year = '"+year+"' ";
		}
		return jdbc.queryForList(sql);
	}
	/**
	 * 
	 * 方法描述   查询记录数量
	 * @author mt.W
	 * @since 2021年10月26日
	 * @param year
	 * @param orgid
	 * @return
	 */
	public int getRecordCount(String year,String orgid){
		String sql = "select count(id) from zzy_jjzw where orgid like '"+orgid+"%' ";
		if(StringUtil.isNotEmpty(year)){
			sql += " and year = '"+year+"' ";
		}
		return jdbc.queryForObject(sql, Integer.class);
	}
	/**
	 * 
	 * 方法描述   新增记录
	 * @author mt.W
	 * @since 2021年10月26日
	 * @param z
	 * @return
	 */
	public int addRecord(ZzyJjzw z){
		String sql = "insert into zzy_jjzw(year,orgid,ylbzmj,ylzcl,gzbzmj,gzzcl,cybzmj,cyzcl,bzzmj,zcl,createTime,createUser) values(?,?,?,?,?,?,?,?,?,?,?,?)";
		return jdbc.update(sql,new Object[]{z.getYear(),z.getOrgid(),z.getYlbzmj(),z.getYlzcl(),z.getGzbzmj(),z.getGzzcl(),z.getCybzmj(),z.getCyzcl(),z.getBzzmj(),z.getZcl(),z.getCreateTime(),z.getCreateUser()});
	}
	/**
	 * 
	 * 方法描述   修改记录
	 * @author mt.W
	 * @since 2021年10月26日
	 * @param z
	 * @return
	 */
	public int editRecord(ZzyJjzw z){
		String sql = "update zzy_jjzw set year=?,ylbzmj=?,ylzcl=?,gzbzmj=?,gzzcl=?,cybzmj=?,cyzcl=?,bzzmj=?,zcl=?,updateTime=?,updateUser=? where id = ?  ";
		return jdbc.update(sql,new Object[]{z.getYear(),z.getYlbzmj(),z.getYlzcl(),z.getGzbzmj(),z.getGzzcl(),z.getCybzmj(),z.getCyzcl(),z.getBzzmj(),z.getZcl(),z.getUpdateTime(),z.getUpdateUser(),z.getId()});
	}
	/**
	 * 
	 * 方法描述  删除记录
	 * @author mt.W
	 * @since 2021年10月26日
	 * @param id
	 * @return
	 */
	public int deleteRecord(String id){
		String sql = "delete from zzy_jjzw where id = ? ";
		return jdbc.update(sql,new Object[]{id});
	}
	public int checkIfExistByYearAndOrg(ZzyJjzw z){
		String sql="select count(id) from zzy_jjzw where year=? and orgid=?";
		if(StringUtil.isNotEmpty(z.getId())){
			sql+=" and id<>"+z.getId();
		}
		return jdbc.queryForObject(sql,new Object[]{z.getYear(),z.getOrgid()}, Integer.class);
	}
}
