/**
 * 版权所有 ©2021 莱欧有限公司
 * 工程名：yearBooks
 * 文件名：ZzyLszwDao.java
 * 创建日期：2021年10月26日 上午9:20:26
 * 作者：mt.W
 */
package com.lion.dao;

import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.stereotype.Repository;

import com.lion.entity.ZzyLszw;

import jodd.util.StringUtil;

/**
 * 类描述   种植业指标-粮食作物统计 Dao
 * @author mt.W
 * @since 2021年10月26日
 */
@Repository
public class ZzyLszwDao {

	@Autowired
	private JdbcTemplate jdbc;
	/**
	 * 
	 * 方法描述   查询记录
	 * @author mt.W
	 * @since 2021年10月26日
	 * @param start
	 * @param limit
	 * @param year
	 * @param orgid
	 * @return
	 */
	public List<Map<String, Object>> getRecordList(int start,int limit,String year,String orgid){
		String sql = "select z.*,o.name orgname from zzy_lszw z left join orgdept o on o.id = z.orgid where z.orgid like '"+orgid+"%' ";
		if(StringUtil.isNotEmpty(year)){
			sql += " and z.year = '"+year+"' ";
		}
		sql += " order by z.year desc limit ?,? ";
		return jdbc.queryForList(sql,new Object[]{start,limit});
	}
	/**
	 * 
	 * 方法描述  查询记录
	 * @author mt.W
	 * @since 2021年10月26日
	 * @param year
	 * @param orgid
	 * @return
	 */
	public List<Map<String, Object>> getRecordList(String year,String orgid){
		String sql = "select z.*,o.name orgname from zzy_lszw z left join orgdept o on o.id = z.orgid where z.orgid like '"+orgid+"%' ";
		if(StringUtil.isNotEmpty(year)){
			sql += " and z.year = '"+year+"' ";
		}
		return jdbc.queryForList(sql);
	}
	/**
	 * 
	 * 方法描述   查询记录数量
	 * @author mt.W
	 * @since 2021年10月26日
	 * @param year
	 * @param orgid
	 * @return
	 */
	public int getRecordCount(String year,String orgid){
		String sql = "select count(id) from zzy_lszw where orgid like '"+orgid+"%' ";
		if(StringUtil.isNotEmpty(year)){
			sql += " and year = '"+year+"' ";
		}
		return jdbc.queryForObject(sql, Integer.class);
	}
	/**
	 * 
	 * 方法描述   新增记录
	 * @author mt.W
	 * @since 2021年10月26日
	 * @param z
	 * @return
	 */
	public int addRecord(ZzyLszw z){
		String sql = "insert into zzy_lszw(year,orgid,lsbzmj,lsmc,lszcl,dgbzmj,dgmc,dgzcl,hsbzmj,hsmc,hszcl,ddbzmj,ddmc,ddzcl,"
				+ "ztbzmj,ztmc,ztzcl,slbzmj,slmc,slzcl,bzzmj,zmc,zcl,createTime,createUser) "
				+ "values(?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?) ";
		return jdbc.update(sql,new Object[]{z.getYear(),z.getOrgid(),z.getLsbzmj(),z.getLsmc(),z.getLszcl(),z.getDgbzmj(),z.getDgmc(),z.getDgzcl(),
				z.getHsbzmj(),z.getHsmc(),z.getHszcl(),z.getDdbzmj(),z.getDdmc(),z.getDdzcl(),z.getZtbzmj(),z.getZtmc(),z.getZtzcl(),z.getSlbzmj(),
				z.getSlmc(),z.getSlzcl(),z.getBzzmj(),z.getZmc(),z.getZcl(),z.getCreateTime(),z.getCreateUser()});
	}
	/**
	 * 
	 * 方法描述  修改记录
	 * @author mt.W
	 * @since 2021年10月26日
	 * @param z
	 * @return
	 */
	public int editRecord(ZzyLszw z){
		String sql = "update zzy_lszw set year=?,lsbzmj=?,lsmc=?,lszcl=?,dgbzmj=?,dgmc=?,dgzcl=?,hsbzmj=?,hsmc=?,hszcl=?,ddbzmj=?,ddmc=?,ddzcl=?,"
				+ "ztbzmj=?,ztmc=?,ztzcl=?,slbzmj=?,slmc=?,slzcl=?,bzzmj=?,zmc=?,zcl=?,updateTime=?,updateUser=? where id = ? ";
		return jdbc.update(sql,new Object[]{z.getYear(),z.getLsbzmj(),z.getLsmc(),z.getLszcl(),z.getDgbzmj(),z.getDgmc(),z.getDgzcl(),
				z.getHsbzmj(),z.getHsmc(),z.getHszcl(),z.getDdbzmj(),z.getDdmc(),z.getDdzcl(),z.getZtbzmj(),z.getZtmc(),z.getZtzcl(),z.getSlbzmj(),
				z.getSlmc(),z.getSlzcl(),z.getBzzmj(),z.getZmc(),z.getZcl(),z.getUpdateTime(),z.getUpdateUser(),z.getId()});
	}
	/**
	 * 
	 * 方法描述   删除记录
	 * @author mt.W
	 * @since 2021年10月26日
	 * @param id
	 * @return
	 */
	public int deleteRecord(String id){
		String sql = "delete from zzy_lszw where id = ? ";
		return jdbc.update(sql,new Object[]{id});
	}
	/**
	 * 
	 * 方法描述   查询年度数据是否存在
	 * @author mt.W
	 * @since 2021年10月26日
	 * @param z
	 * @return
	 */
	public int checkIfExistByYearAndOrg(ZzyLszw z){
		String sql="select count(id) from zzy_lszw where year=? and orgid=?";
		if(StringUtil.isNotEmpty(z.getId())){
			sql+=" and id<>"+z.getId();
		}
		return jdbc.queryForObject(sql,new Object[]{z.getYear(),z.getOrgid()}, Integer.class);
	}
}
