/**
 * 版权所有 ©2020 莱欧有限公司
 * 工程名：base02
 * 文件名：LoginService.java
 * 创建日期：2020年12月23日 下午3:55:14
 * 作者：mt.W
 */
package com.lion.service;

import java.awt.Color;
import java.awt.Font;
import java.awt.Graphics;
import java.awt.image.BufferedImage;
import java.io.IOException;
import java.util.List;
import java.util.Map;
import java.util.Random;

import javax.imageio.ImageIO;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import com.lion.config.UserLoginRecordCache;
import org.apache.log4j.Logger;
import org.json.JSONObject;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.lion.controller.LoginController;
import com.lion.dao.LogDao;
import com.lion.dao.LoginDao;
import com.lion.dao.UserDao;
import com.lion.entity.LoginUserInfo;
import com.lion.util.AuthorizeCheck;
import com.lion.util.HttpUtil;
import com.lion.util.MD5Util;
import com.lion.util.RasUtil;
import com.lion.util.TimeUtil;
import com.lion.util.TokenUtil;
import com.lion.util.Util;

import jodd.util.StringUtil;

/**
 * 类描述
 * @author mt.W
 * @since 2020年12月23日
 */
@Service
public class LoginService {
	@Autowired
	private LoginDao dao;
	@Autowired
	private UserDao userDao;
	@Autowired
	private LogDao logDao;
	public Logger log4j=Logger.getLogger(LoginController.class);
	/** 
	 * 方法描述  组织机构用户登录
	 * @author dlm
	 * @since 2019年3月14日
	 * @param req
	 * @param session
	 * @param userName
	 * @param password
	 * @param code
	 * @return	
	 */
	public String userLoginManager(HttpServletRequest req,HttpServletResponse res,HttpSession session,String userName,String password,String code,String private_key){
		if(StringUtil.isEmpty(userName)){
			return Util.responseString("false","用户名不能为空");
		}
		if(StringUtil.isEmpty(password)){
			return Util.responseString("false","密码不能为空");
		}
		String sessionCode=(String)session.getAttribute("ecode");
		if(!code.equalsIgnoreCase(sessionCode)){
			return Util.responseString("false","验证码错误");
		}

		String validateResult = UserLoginRecordCache.BeginUserLogin(userName);
		if(null != validateResult)
			return Util.responseString("false", validateResult);

		try {
			password = RasUtil.decrypt(password, private_key);
		} catch (Exception e) {
			e.printStackTrace();
		}
		
		List<Map<String,Object>> list=userDao.checkUserLogin(userName);
		if(list.size()>0){//登录成功
			String kupwd=list.get(0).get("pwd").toString();
			boolean result =  AuthorizeCheck.validatePassword(password,kupwd);
			if(result){
				String userId=list.get(0).get("id").toString();
				String roleId=list.get(0).get("roleid").toString();//角色id
				if(StringUtil.isEmpty(roleId)){
					UserLoginRecordCache.EndUserLogin(userName, false);
					return Util.responseString("false","该用户未分配角色，禁止登录");
				}
				String cookie=MD5Util.StringInMd5(userId+TimeUtil.getNowTimeTwo());
				int l=logDao.saveLoginInfo(userId, cookie);
				if(l>0){
					dao.deleteLoginStatus(userId);
					LoginUserInfo userInfo=new LoginUserInfo();
					userInfo.setUserId(userId);
					userInfo.setUserAccount(userName);
					userInfo.setOrgid(list.get(0).get("orgid").toString());
					userInfo.setRoleid(roleId);
					TokenUtil.setLoginUserInfo(cookie, userInfo);
					logDao.saveLog("用户登录:"+userName,"登录", userId);
					
					JSONObject json=new JSONObject();
					json.put("success","true");
					json.put("message",cookie);
					json.put("orgid",list.get(0).get("orgid").toString());
					UserLoginRecordCache.EndUserLogin(userName, true);
					return json.toString();
				}else{
					UserLoginRecordCache.EndUserLogin(userName, false);
					return Util.responseString("false","登录失败");
				}
			}else{
				UserLoginRecordCache.EndUserLogin(userName, false);
				return Util.responseString("false","密码错误");
			}
		}
		UserLoginRecordCache.EndUserLogin(userName, false);
		return Util.responseString("false","用户名或密码不存在");
	}
	
	/**
	 * 方法描述 根据当前用户登录的角色获取资源
	 * @author dlm
	 * @since 2019年2月27日
	 * @param req
	 * @return	
	 */
	public Map<String,Object> getResourcesByRole(HttpServletRequest req,HttpSession session){
		LoginUserInfo s=TokenUtil.getUserInfo(req);
		List<Map<String,Object>> list=dao.getResourcesByRoleId(s.getRoleid());
		Map<String,Object> map=Util.responseMap("true",ResourceService.returnRecourceTreeList(list));
		return map;
	}
	/**
	 * 方法描述  安全退出
	 * @author dlm
	 * @since 2019年3月1日
	 * @param req
	 * @param session
	 * @return	
	 */
	public String loginOut(HttpServletRequest req,HttpSession session){
		return Util.responseString("true", "../login.html");
	}
	/**
	 * 方法描述  生成验证码
	 * @author dlm
	 * @since 2019年3月1日
	 * @param req
	 * @param timestamp  时间戳
	 * @return	
	 * @throws IOException 
	 */
	public void createImg(HttpServletRequest req,HttpSession session,String timestamp,HttpServletResponse res) throws IOException{
		String str="ABCDEFGHIGKLMNOPQRSTUVWXYZ0123456789";
		int width=80;//宽度
		int height=38;//验证码高度
		BufferedImage buffImg = new BufferedImage(width, height, BufferedImage.TYPE_INT_RGB);
		Graphics gd = buffImg.getGraphics();
		gd.setColor(Color.WHITE);
		gd.fillRect(0, 0, width, height);
		Random r = new Random();
		StringBuffer sb = new StringBuffer();
		for (int i = 0; i < 4; i++) {
			gd.setColor(new Color(r.nextInt(88), r.nextInt(210), r.nextInt(150)));
			String code=str.charAt(new Random().nextInt(str.length()))+"";
			gd.setFont(new Font("微软雅黑",Font.PLAIN,22));//字体及大小
			gd.drawString(code, 15 * i + 7, 27);
			sb.append(code);
		}
		session.setAttribute("ecode",sb.toString());
		gd.drawRect(0, 0, width - 1, height - 1);
		ImageIO.write(buffImg, "jpg", res.getOutputStream());
	}
	
	/**
	 * 方法描述	修改密码
	 * @author cpf
	 * @since 2019年3月7日
	 * @return	
	 */
	public String updatePassword(HttpServletRequest req,HttpSession session,String password,String confirm_password){
		LoginUserInfo s=TokenUtil.getUserInfo(req);
		int rs;
		if(password.equals(confirm_password)){
			rs = dao.updateManagerPassword(password, s.getUserId());//管理员登录情况下密码修改
		}else{
			return Util.responseString("false","两次密码不一致");
		}
		if(rs>0){
			logDao.saveLog(s.getUserAccount()+"进行密码修改密码:","密码修改", s.getUserId());
			return Util.responseString("true","修改成功");
		}
		return Util.responseString("false","修改失败");
	}
	/**
	 * 
	 * 方法描述  钉钉登录
	 * @author mt.W
	 * @since 2019年9月26日
	 * @param req
	 * @param phone
	 * @param password
	 * @return
	 */
	public String userLoginManager(HttpServletRequest req,String phone,String password){
		if(StringUtil.isEmpty(phone)){
			return Util.responseString("false","用户名不能为空");
		}
		if(StringUtil.isEmpty(password)){
			return Util.responseString("false","密码不能为空");
		}
		List<Map<String,Object>> list=userDao.checkUserLogin(phone);
		if(list.size()>0){
			String kupwd=list.get(0).get("pwd").toString();
			boolean result =  AuthorizeCheck.validatePassword(password,kupwd);
			if(result){
				String userId=list.get(0).get("id").toString();
				String roleId=list.get(0).get("roleid").toString();//角色id
				String name=list.get(0).get("name").toString();
				String orgid = list.get(0).get("orgid").toString();
				if(StringUtil.isEmpty(roleId)){
					return Util.responseString("false","该用户未分配角色，禁止登录");
				}
				JSONObject json=new JSONObject();
				json.put("success","true");
				json.put("userId",userId);
				json.put("roleId",roleId);
				json.put("name",name);
				json.put("orgid",orgid);
				return json.toString();
			}else{
				return Util.responseString("false","用户名或密码不存在");
			}
		}
		return Util.responseString("false","用户名或密码不存在");
	}
	public Map<String,Object> returnUserInfo(HttpServletRequest req){
		LoginUserInfo userinfo=TokenUtil.getUserInfo(req);
		List<Map<String,Object>> list = userDao.getUserInfoById(userinfo.getUserId());
		return list.get(0);
	}
	public void loginOut(HttpSession session,String url){
		if(session.getAttribute("longinJOSONID")!=null){
			dao.deleteLoginStatusByCookie(session.getAttribute("longinJOSONID").toString());
			session.removeAttribute("longinJOSONID");
		}
		
		String rs = HttpUtil.httpGet(url);
		logDao.saveLog("退出登录请求"+url+"返回结果:"+rs, "退出登录", "0");
	}
}
